@@ -10,7 +10,6 @@ import json
 from typing import Collection
 
 import kser.entry
-import kser.controller
 import kser.sequencing.operation
 from cdumay_result import Result
 from kser import __version__ as kversion, __hostname__
@@ -37,20 +36,12 @@ def _with_tracer_wrapper(func):
 
 
 @_with_tracer_wrapper
-def _winject(_tracer, wrapped, _, args, kwargs):
+def _winject(_tracer, wrapped, instance, args, kwargs):
     """Inject current trace context into message"""
-    tracing = dict()
-    get_global_textmap().inject(carrier=tracing)
-
-    if len(tracing) > 0:
-        if "kmsg" in kwargs:
-            if isinstance(kwargs['kmsg'], Message):
-                kwargs['kmsg'].metadata.update(tracing=tracing)
-        else:
-            for arg in args:
-                if isinstance(arg, Message):
-                    arg.metadata.update(tracing=tracing)
-                    break
+    trace_info = dict()
+    get_global_textmap().inject(carrier=trace_info)
+    if len(trace_info) != 0:
+        instance.metadata.update(tracing=trace_info)
     return wrapped(*args, **kwargs)
 
 
@@ -80,7 +71,6 @@ def _wtrigger(tracer, wrapped, instance, args, kwargs):
             span.set_attribute(f'{prefix}.status', instance.status)
             span.set_attribute(f'{prefix}.name', instance.__class__.path)
             span.set_attribute(f'{prefix}.trigger', trigger_name)
-            span.set_attribute(f'{prefix}.params', json.dumps(instance.params))
             span.set_attribute(
                 f'{prefix}.metadata', json.dumps(instance.metadata)
             )
@@ -91,9 +81,6 @@ def _wtrigger(tracer, wrapped, instance, args, kwargs):
                 span.set_attribute(f'{prefix}.retcode', result.retcode)
                 span.set_attribute(f'{prefix}.stdout', result.stdout)
                 span.set_attribute(f'{prefix}.stderr', result.stderr)
-                span.set_attribute(
-                    f'{prefix}.retval', json.dumps(result.retval)
-                )
         return result
 
 
@@ -110,7 +97,8 @@ class KserInstrumentor(BaseInstrumentor):
         tracer = get_tracer(__name__, __version__, tracer_provider)
 
         # Serialization
-        _wrap(kser, "controller.BaseProducer.send", _winject(tracer))
+        _wrap(kser, "schemas.Message.dump", _winject(tracer))
+        _wrap(kser, "schemas.Message.dumps", _winject(tracer))
 
         # tasks & operations
         # _wrap(kser, "entry.Entrypoint._post_init", _wtrigger(tracer))
@@ -152,8 +140,8 @@ class KserInstrumentor(BaseInstrumentor):
         )
 
     def _uninstrument(self, **kwargs):
-        unwrap(kser.controller.BaseProducer, "send")
-
+        unwrap(kser.schemas.Message, "dump")
+        unwrap(kser.schemas.Message, "dumps")
         unwrap(kser.entry.Entrypoint, "_prerun")
         unwrap(kser.entry.Entrypoint, "_postrun")
         unwrap(kser.entry.Entrypoint, "_run")
